@@ -160,16 +160,18 @@ class Query(object):
 
         for filter_statement in self.filters:
 
+            print(isinstance(filter_statement.value, str))
+
             if isinstance(filter_statement.value, str):
                 query_data += ' FILTER %s.%s %s "%s"' % (
-                    filter_statement.collection,
+                    self._get_collection_ident(filter_statement.collection),
                     filter_statement.attribute,
                     filter_statement.operator,
                     filter_statement.value,
                 )
             else:
                 query_data += ' FILTER %s.%s %s %s' % (
-                    filter_statement.collection,
+                    self._get_collection_ident(filter_statement.collection),
                     filter_statement.attribute,
                     filter_statement.operator,
                     filter_statement.value,
